@@ -14,7 +14,7 @@ sub com_rt {
     my $message = "";
     $message = join( " ", @messages ) if @messages;
     my $tweet = $self->status->[ $id ];
-    $self->client->update( $message.' RT @'.$tweet->{user}{screen_name}. ': '. encode( "utf8", $tweet->{text} ) );
+    $self->tweet( $message.' RT @'.$tweet->{user}{screen_name}. ': '. encode( "utf8", $tweet->{text} ) );
     $self->com_ft;
     1;
 }
